@@ -17,13 +17,13 @@ my $url = 'http://127.0.0.1/';
 my @try = (
     [ 'AnyEvent::HTTPD' ],
     [ 'HTTP::Server::PSGI' ],
-    [ 'HTTP::Server::PSGI', ' (workers=10)', max_workers => 10 ],
     [ 'Twiggy' ],
     [ 'HTTP::Server::Simple' ],
     [ 'Corona' ],
     [ 'Danga::Socket' ],
     [ '+POE::Component::Server::PSGI' ],
     [ 'Starman', ' (workers=10)', workers => 10 ],
+    [ 'Starlet', ' (workers=10)', max_workers => 10 ],
 );
 
 my @backends;
