@@ -2,6 +2,7 @@ package HTTP::Server::PSGI;
 use strict;
 use warnings;
 
+use Carp ();
 use Plack;
 use Plack::HTTPParser qw( parse_http_request );
 use IO::Socket::INET;
@@ -41,23 +42,16 @@ sub new {
         max_keepalive_reqs => $args{max_keepalive_reqs},
         server_software    => $args{server_software} || $class,
         server_ready       => $args{server_ready} || sub {},
-        max_workers        => $args{max_workers} || 1,
         max_reqs_per_child => $args{max_reqs_per_child} || 100,
+        max_keepalive_reqs => 1,
+        is_multiprocess    => Plack::Util::FALSE,
     }, $class;
 
-    if ($self->{max_workers} > 1) {
-        try {
-            require Parallel::Prefork;
-            $self->{prefork} = 1;
-            $self->{max_keepalive_reqs} ||= 100;
-            $self->{server_software} .= " (prefork)";
-        } catch {
-            die "You need to install Parallel::Prefork to run multi workers (max_workers=$self->{max_workers}): $_";
-        };
-    }
-
-    unless ($self->{prefork}) {
-        $self->{max_keepalive_reqs} ||= 1;
+    if ($args{max_workers} && $args{max_workers} > 1) {
+        Carp::carp(
+            "Preforking in $class is deprecated. Falling back to the non-forking mode. ",
+            "If you need preforking, use Starman or Starlet instead and run like `plackup -s Starlet`",
+        );
     }
 
     $self;
@@ -66,12 +60,7 @@ sub new {
 sub run {
     my($self, $app) = @_;
     $self->setup_listener();
-
-    if ($self->{prefork}) {
-        $self->run_prefork($app);
-    } else {
-        $self->accept_loop($app);
-    }
+    $self->accept_loop($app);
 }
 
 sub setup_listener {
@@ -87,24 +76,6 @@ sub setup_listener {
     $self->{server_ready}->($self);
 }
 
-sub run_prefork {
-    my($self, $app) = @_;
-
-    my $pm = Parallel::Prefork->new({
-        max_workers => $self->{max_workers},
-        trap_signals => {
-            TERM => 'TERM',
-            HUP  => 'TERM',
-        },
-    });
-    while ($pm->signal_received ne 'TERM') {
-        $pm->start and next;
-        $self->accept_loop($app, $self->{max_reqs_per_child});
-        $pm->finish;
-    }
-    $pm->wait_all_children;
-}
-
 sub accept_loop {
     # TODO handle $max_reqs_per_child
     my($self, $app, $max_reqs_per_child) = @_;
@@ -131,10 +102,11 @@ sub accept_loop {
                     'psgi.url_scheme' => 'http',
                     'psgi.run_once'     => Plack::Util::FALSE,
                     'psgi.multithread'  => Plack::Util::FALSE,
-                    'psgi.multiprocess' => $self->{prefork},
+                    'psgi.multiprocess' => $self->{is_multiprocess},
                     'psgi.streaming'    => Plack::Util::TRUE,
                     'psgi.nonblocking'  => Plack::Util::FALSE,
                     'psgix.input.buffered' => Plack::Util::TRUE,
+                    'psgix.io'          => $conn,
                 };
 
                 # no need to take care of pipelining since this module is a HTTP/1.0 server
@@ -146,6 +118,7 @@ sub accept_loop {
                     or last;
                 # TODO add special cases for clients with broken keep-alive support, as well as disabling keep-alive for HTTP/1.0 proxies
             }
+            $conn->close;
         }
     }
 }
@@ -349,13 +322,17 @@ HTTP::Server::PSGI is a standalone, single-process and PSGI compatible
 HTTP server implementations. It runs reasonably fast and HTTP/1.0 and
 Keep-Alive requests are supported.
 
-This server should be great for the development and testing, but not
-suitable for production. See L<HTTP::Server::PSGI::Prefork> if you
-want a multi-process prefork server.
+This server should be great for the development and testig, but might
+not be suitable for production.
 
 Some features in HTTP/1.1, notably chunked requests, responses and
 pipeline requests are B<NOT> supported yet.
 
+=head1 PREFORKING
+
+L<HTTP::Server::PSGI> does B<NOT> support preforking. See L<Starman>
+or L<Starlet> if you want a multi-process prefork web servers.
+
 =head1 AUTHOR
 
 Kazuho Oku
@@ -364,6 +341,6 @@ Tatsuhiko Miyagawa
 
 =head1 SEE ALSO
 
-L<Plack::Handler::Standalone>
+L<Plack::Handler::Standalone> L<Starman> L<Starlet>
 
 =cut
